@@ -206,9 +206,9 @@ def verify_config(verbose=True):
     else:
         dollarFormat = "{:.2f}".format(base_pay)
 
-        if base_pay <= 0:
+        if base_pay < 0:
             log(
-                "✗ base_payment must be positive value in config.txt.",
+                "✗ base_payment must be greater than or equal to zero in config.txt.",
                 chevrons=False,
                 verbose=verbose,
             )
